aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rwxr-xr-xmake_slackware_live.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/make_slackware_live.sh b/make_slackware_live.sh
index 2c0f1f1..5c1bcf6 100755
--- a/make_slackware_live.sh
+++ b/make_slackware_live.sh
@@ -161,7 +161,7 @@ ONLY_ISO="NO"
# The name of the directory used for storing persistence data:
PERSISTENCE=${PERSISTENCE:-"persistence"}
# Add a Core OS to load into RAM (currently only supported for XFCE and LEAN):
CORE2RAM=${CORE2RAM:-"NO"}
CORE2RAMMODS="${MINLIST} noxbase"
@@ -1204,7 +1204,7 @@ case "$LIVEDE" in
;;
esac
-if [ "${CORE2RAM}" == "YES" ] || [ "${LIVEDE}" == "XFCE" ] || [ "${LIVEDE}" == "LEAN" ] ; then
+if [ "${CORE2RAM}" == "YES" ] || [ "${LIVEDE}" == "XFCE" ] || [ "${LIVEDE}" == "LEAN" ] || [ "${LIVEDE}" == "DAW" ] ; then
# For now, allow CORE2RAM only for the variants that actually
# have the required modules in their system list.
# TODO: create these modules separately in the 'core2ram' subdirectory.
@@ -161,7 +161,7 @@ ONLY_ISO="NO"
# The name of the directory used for storing persistence data:
PERSISTENCE=${PERSISTENCE:-"persistence"}
-# Add a Core OS to load into RAM (currently only supported for XFCE and LEAN):
+# Add a Core OS to load into RAM (currently supported for XFCE, LEAN, DAW):
CORE2RAM=${CORE2RAM:-"NO"}
CORE2RAMMODS="${MINLIST} noxbase"